@@ -1,20 +1,8 @@
-#
-# This file is part of Metabase-Fact
-#
-# This software is Copyright (c) 2010 by David Golden.
-#
-# This is free software, licensed under:
-#
-#   The Apache License, Version 2.0, January 2004
-#
 use 5.006;
 use strict;
 use warnings;
 package Metabase::Resource::perl::commit;
-BEGIN {
-  $Metabase::Resource::perl::commit::VERSION = '0.019';
-}
-# ABSTRACT: class for Metabase resources about perl commits
+our $VERSION = '0.020'; # VERSION
 
 use Carp ();
 
@@ -53,6 +41,10 @@ sub full_url {
 sub validate { 1 }
 
 
+1;
+
+# ABSTRACT: class for Metabase resources about perl commits
+
 
 
 =pod
@@ -63,7 +55,7 @@ Metabase::Resource::perl::commit - class for Metabase resources about perl commi
 
 =head1 VERSION
 
-version 0.019
+version 0.020
 
 =head1 SYNOPSIS
 
@@ -129,7 +121,7 @@ H.Merijn Brand <hmbrand@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2010 by David Golden.
+This software is Copyright (c) 2011 by David Golden.
 
 This is free software, licensed under:
 
